import numpy as np
import matplotlib.pyplot as plt
import pystan
import matplotlib.pyplot as plt
import seaborn as sb

sm = pystan.StanModel(file = 'choco_choice.stan')

freq_noclip = [55, 24, 16]
freq_clip = [38, 27, 30]

Data = {'freq_1': freq_noclip, 'freq_2':freq_clip}

fit = sm.sampling(data = Data)
print(fit)

ent1_hat = np.median(fit['entropy1'])
ent2_hat = np.median(fit['entropy2'])

sb.kdeplot(fit['entropy1'], label = 'No-clip')
sb.kdeplot(fit['entropy2'], label = 'Clip')
plt.title('Entropy: No-clip={0:.2f}, Clip={1:.2f}'.format(ent1_hat, ent2_hat))
plt.legend()
plt.savefig('FigEntropies.png')
plt.show()
plt.close()

p1_1_hat = np.median(fit['p1'].T[0])
p1_2_hat = np.median(fit['p1'].T[1])
p1_3_hat = np.median(fit['p1'].T[2])
sb.kdeplot(fit['p1'].T[0], label = 'p1[1]:Ghana')
sb.kdeplot(fit['p1'].T[1], label = 'p1[2]:Venezuela')
sb.kdeplot(fit['p1'].T[2], label = 'p1[3]:Equador')
plt.legend()
plt.title('No-clip\nGhana={0:.2f},  Venezuela={1:.2f},  Equador={2:.2f}'.format(
            p1_1_hat, p1_2_hat, p1_3_hat))
plt.savefig('Figp1.png')
plt.show()
plt.close()

p2_1_hat = np.median(fit['p2'].T[0])
p2_2_hat = np.median(fit['p2'].T[1])
p2_3_hat = np.median(fit['p2'].T[2])
sb.kdeplot(fit['p2'].T[0], label = 'p2[1]:Ghana')
sb.kdeplot(fit['p2'].T[1], label = 'p2[2]:Venezuela')
sb.kdeplot(fit['p2'].T[2], label = 'p2[3]:Equador')
plt.legend()
plt.title('Clip\nGhana={0:.2f},  Venezuela={1:.2f},  Equador={2:.2f}'.format(
            p2_1_hat, p2_2_hat, p2_3_hat))
plt.savefig('Figp2.png')
plt.show()
plt.close()

ck_count = 0
e1_smpls = fit['entropy1']
e2_smpls = fit['entropy2']
e1_smpls = np.sort(e1_smpls)
e2_smpls = np.sort(e2_smpls)

def SmallerEqProp(a, v):
    i = 0
    while v > a[i]:
        i += 1
        if i >= len(a):
            break
    prop = i / len(a)
    return prop

sum_prop = 0.0
for v in e1_smpls:
    sum_prop += (1 - SmallerEqProp(e2_smpls, v))
prop_Larger = sum_prop / len(e1_smpls)
print('Prop_Larger =', prop_Larger)
